instrumenttools.Piano
=====================

.. abjad-lineage:: abjad.tools.instrumenttools.Piano.Piano.Piano

.. autoclass:: abjad.tools.instrumenttools.Piano.Piano.Piano
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Piano.Piano.Piano.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Piano.Piano.Piano.__repr__
   :noindex:
